<?php

namespace App\Http\Resources;

use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class UserDashboardServicePackageResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @return array<string, mixed>
     */
    public function toArray(Request $request): array
    {
        $locale = $request->header('Accept-Lang') ?? app()->getLocale();
        return [
            'id' => $this->id,
            'hexa_code' => $this?->hexa_code,
            'title' => $this?->title,
            'price' => $this?->price,
            'description' => $this?->description,
            'user' => $this?->whenLoaded('user'),
            'services' => $this?->whenLoaded('services'),
            'media' => $this?->getFilteredMedia($locale),
        ];
    }

    private function getFilteredMedia($locale)
    {
        return $this->whenLoaded('media', function () use ($locale) {
            return $this->media->filter(function ($media) use ($locale) {
                return isset($media->custom_properties['language']) &&
                    $media->custom_properties['language'] === $locale;
            })->map(function ($media) {
                return collect($media)->only(['original_url','collection_name','id']);
            })->values();
        }, []);
    }
}
